/*_############################################################################
  _## 
  _##  SNMP4J-Model - SimpleMibTableBrowser.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.demo.mibbrowser;

import com.snmp4j.smi.SmiManager;
import com.snmp4j.smi.SmiObjectType;
import org.snmp4j.Target;
import org.snmp4j.model.mapper.VariableBindingMapper;
import org.snmp4j.model.snmp.proxy.SnmpProxyRow;
import org.snmp4j.model.snmp.proxy.SnmpTable;
import org.snmp4j.model.snmp.proxy.impl.SnmpColumn;
import org.snmp4j.model.snmp.proxy.impl.SnmpIndexColumn;
import org.snmp4j.model.snmp.proxy.impl.SnmpProxyObjectHelper;
import org.snmp4j.model.snmp.spi.SnmpService;
import org.snmp4j.smi.OID;
import org.snmp4j.smi.VariableBinding;

import javax.swing.*;
import javax.swing.table.TableColumnModel;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.*;
import java.util.List;

/**
 * The SimpleMibTableBrowser class is a Swing panel that displays a SNMP table.
 *
 * @author Frank Fock
 */
public abstract class SimpleMibTableBrowser {

  private SnmpService snmpService;
  private SmiManager smiManager;
  private Target target;
  private VariableBindingMapper variableBindingMapper;

  SnmpTable table;


  private JTable snmpTable;
  private TableColumnModel columnModel;
  private JButton refreshButton;
  private JButton saveButton;
  private JButton closeButton;
  private JPanel rootPanel;
  private JButton addButton;

  public SimpleMibTableBrowser(final SnmpTable table, final TableColumnModel columnModel,
                               final SnmpService snmpService, final SmiManager smiManager, final Target target,
                               final VariableBindingMapper variableBindingMapper) {
    this.table = table;
    this.smiManager = smiManager;
    this.columnModel = columnModel;
    this.snmpService = snmpService;
    this.target = target;
    this.variableBindingMapper = variableBindingMapper;

    $$$setupUI$$$();
    refreshButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent e) {
        table.reload(snmpService, target, variableBindingMapper, null);
      }
    });
    closeButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent e) {
        close();
      }
    });
    saveButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent e) {
        table.getCommitter().commitChanges(table);
      }
    });
    addButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent e) {
        String indexString =
            JOptionPane.showInputDialog(this, "Row index value:");
        if (indexString != null) {
          SnmpColumn firstColumn = (SnmpColumn) table.getColumns().get(0);
          OID indexOID = new OID(firstColumn.getOID() + "." + indexString);
          indexOID = new OID(indexOID.getValue(), firstColumn.getOID().size(), indexOID.size() - firstColumn.getOID().size());
          List<VariableBinding> indexVBs = table.getIndexVariableBindings(indexOID);
          List<VariableBinding> initialVBs = new ArrayList<VariableBinding>();
          for (SnmpColumn snmpColumn : (List<SnmpColumn>) table.getColumns()) {
            OID cellOID = new OID(snmpColumn.getOID().getValue(), indexOID.getValue());
            SmiObjectType objectType = (SmiObjectType) smiManager.findSmiObject(snmpColumn.getOID());
            VariableBinding vb = new VariableBinding(cellOID, objectType.createNewVariable());
            initialVBs.add(vb);
          }
          SnmpProxyRow newRow = table.getRowFactory().createProxyRow(indexOID,
              SnmpProxyObjectHelper.mapVBsToObjects(variableBindingMapper, indexVBs, (List<SnmpIndexColumn>) table.getIndexColumns()),
              SnmpProxyObjectHelper.mapVBsToObjects(variableBindingMapper, initialVBs, table.getColumns()));
          table.insertRow(newRow);
        }
      }
    });
  }

  public abstract void close();

  private void createUIComponents() {
    snmpTable = new JTable(table, columnModel);
  }

  /**
   * Method generated by IntelliJ IDEA GUI Designer
   * >>> IMPORTANT!! <<<
   * DO NOT edit this method OR call it in your code!
   *
   * @noinspection ALL
   */
  private void $$$setupUI$$$() {
    createUIComponents();
    rootPanel = new JPanel();
    rootPanel.setLayout(new GridBagLayout());
    final JPanel spacer1 = new JPanel();
    GridBagConstraints gbc;
    gbc = new GridBagConstraints();
    gbc.gridx = 2;
    gbc.gridy = 0;
    gbc.fill = GridBagConstraints.HORIZONTAL;
    rootPanel.add(spacer1, gbc);
    final JPanel panel1 = new JPanel();
    panel1.setLayout(new FlowLayout(FlowLayout.RIGHT, 5, 5));
    gbc = new GridBagConstraints();
    gbc.gridx = 0;
    gbc.gridy = 1;
    gbc.fill = GridBagConstraints.BOTH;
    rootPanel.add(panel1, gbc);
    refreshButton = new JButton();
    refreshButton.setText("Refresh");
    panel1.add(refreshButton);
    addButton = new JButton();
    addButton.setText("Add Row");
    panel1.add(addButton);
    saveButton = new JButton();
    saveButton.setText("Save");
    panel1.add(saveButton);
    closeButton = new JButton();
    closeButton.setText("Close");
    panel1.add(closeButton);
    final JScrollPane scrollPane1 = new JScrollPane();
    gbc = new GridBagConstraints();
    gbc.gridx = 0;
    gbc.gridy = 0;
    gbc.weightx = 1.0;
    gbc.weighty = 1.0;
    gbc.fill = GridBagConstraints.BOTH;
    gbc.insets = new Insets(10, 10, 10, 10);
    rootPanel.add(scrollPane1, gbc);
    scrollPane1.setViewportView(snmpTable);
  }

  /**
   * @noinspection ALL
   */
  public JComponent $$$getRootComponent$$$() {
    return rootPanel;
  }
}
