/*_############################################################################
  _## 
  _##  SNMP4J-Model - SimpleMibTreeTableModelAdapter.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.demo.mibbrowser;

import javax.swing.*;
import javax.swing.event.TreeExpansionEvent;
import javax.swing.event.TreeExpansionListener;
import javax.swing.table.AbstractTableModel;
import javax.swing.tree.TreePath;

/**
 * The <code>SimpleMibTreeTableModelAdapter</code> provides a tree table model for a tree node's table.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class SimpleMibTreeTableModelAdapter extends AbstractTableModel {

    private JTree tree;
    private SimpleAbstractTreeTableModel treeTableModel;

    public SimpleMibTreeTableModelAdapter(SimpleAbstractTreeTableModel treeTableModel, JTree tree) {
      this.tree = tree;
      this.treeTableModel = treeTableModel;

      tree.addTreeExpansionListener(new TreeExpansionListener() {
        public void treeExpanded(TreeExpansionEvent event) {
          fireTableDataChanged();
        }

        public void treeCollapsed(TreeExpansionEvent event) {
          fireTableDataChanged();
        }
      });
    }

    public int getColumnCount() {
      return treeTableModel.getColumnCount();
    }

    public String getColumnName(int column) {
      return treeTableModel.getColumnName(column);
    }

    public Class<?> getColumnClass(int column) {
      return treeTableModel.getColumnClass(column);
    }

    public int getRowCount() {
      return tree.getRowCount();
    }

    protected Object nodeForRow(int row) {
      TreePath treePath = tree.getPathForRow(row);
      return treePath.getLastPathComponent();
    }

    public Object getValueAt(int row, int column) {
      return treeTableModel.getValueAt(nodeForRow(row), column);
    }

    public boolean isCellEditable(int row, int column) {
      return treeTableModel.isCellEditable(nodeForRow(row), column);
    }

    public void setValueAt(Object value, int row, int column) {
      treeTableModel.setValueAt(value, nodeForRow(row), column);
    }

}
