/*_############################################################################
  _## 
  _##  SNMP4J-Model - SimpleTreeTableModel.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.demo.mibbrowser;

import javax.swing.tree.TreeModel;

/**
 * The SimpleTreeTableModel defines the interface for a simple tree table model.
 *
 * @author Frank Fock
 * @version 1.0
 */
public interface SimpleTreeTableModel extends TreeModel {


  /**
   * Returns the number of available columns.
   * @return the number of columns.
   */
  public int getColumnCount();

  /**
   * Returns the column name.
   * @param column
   *    the column number (zero based).
   * @return
   *    the name of the specified column.
   */
  public String getColumnName(int column);


  /**
   * Returns the type (class) of a column.
   * @param column Column number
   * @return Class
   */
  public Class<?> getColumnClass(int column);

  /**
   * Returns the value of a node in a column.
   * @param node
   *    the node object.
   * @param column
   *   the column number (zero based).
   * @return Value of the node in the column
   */
  public Object getValueAt(Object node, int column);


  /**
   * Checks if a cell of a node in one column is editable.
   * @param node
   *    the node object.
   * @param column
   *    the column number (zero based).
   * @return true/false
   */
  public boolean isCellEditable(Object node, int column);

  /**
   * Sets a value for a node in one column.
   * @param aValue
   *    the new value for the column.
   * @param node
   *    the tree node.
   * @param column
   *    the column number (zero based).
   */
  public void setValueAt(Object aValue, Object node, int column);


}
