/*_############################################################################
  _## 
  _##  SNMP4J-Model - GlobalTransaction.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.api;

import org.snmp4j.model.transaction.SnmpTransaction;

/**
 * The <code>GlobalTransaction</code> implements a {@link org.snmp4j.model.transaction.SnmpTransaction}
 * with rollback marker and an auto-commit option.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class GlobalTransaction implements SnmpTransaction {

  private boolean rollbackOnly;
  private boolean autocommit;

  /**
   * Creates a transaction with autocommit on or off.
   * @param autocommit
   *   <code>true</code> if autocommit is turned on, otherwise <code>false</code>.
   *   With autocommit on, changes are immediately sent to the agent (command responder).
   *   Otherwise, they are collected until an explicit commit is performed.
   */
  public GlobalTransaction(boolean autocommit) {
    this.autocommit = autocommit;
  }

  @Override
  public void setRollbackOnly() {
    rollbackOnly = true;
  }

  @Override
  public boolean isRollbackOnly() {
    return rollbackOnly;
  }

  @Override
  public boolean isAutoCommit() {
    return autocommit;
  }

  @Override
  public String toString() {
    return "GlobalTransaction{" +
        "rollbackOnly=" + rollbackOnly +
        ", autocommit=" + autocommit +
        '}';
  }
}
