package org.snmp4j.model.snmp.api;

import org.snmp4j.smi.OctetString;

import java.util.Arrays;
import java.util.Comparator;

/**
 * The {@link SnmpProxyId} object represents an unique ID for {@link org.snmp4j.model.snmp.proxy.SnmpProxyObject}
 * instances. Unless MIB modules are using the same object names within their modules, the module name could be
 * <code>null</code>. The <code>null</code> or empty context name represents the default context.
 *
 * @author Frank Fock
 */
public class SnmpProxyId implements Comparable<SnmpProxyId> {
  private String moduleName;
  private String objectName;
  private Object[] indexValues;
  private OctetString contextName;

  public SnmpProxyId(OctetString contextName, String moduleName, String objectName, Object... indexValues) {
    this.contextName = contextName;
    this.moduleName = moduleName;
    this.objectName = objectName;
    this.indexValues = indexValues;
  }

  public OctetString getContextName() {
    return contextName;
  }

  public Object[] getIndexValues() {
    return indexValues;
  }

  public String getModuleName() {
    return moduleName;
  }

  public String getObjectName() {
    return objectName;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;

    SnmpProxyId that = (SnmpProxyId) o;

    if (moduleName != null ? !moduleName.equals(that.moduleName) : that.moduleName != null) return false;
    if (!objectName.equals(that.objectName)) return false;
    // Probably incorrect - comparing Object[] arrays with Arrays.equals
    if (!Arrays.equals(indexValues, that.indexValues)) return false;
    return contextName != null ? contextName.equals(that.contextName) : that.contextName == null;

  }

  @Override
  public int hashCode() {
    int result = moduleName != null ? moduleName.hashCode() : 0;
    result = 31 * result + objectName.hashCode();
    result = 31 * result + Arrays.hashCode(indexValues);
    result = 31 * result + (contextName != null ? contextName.hashCode() : 0);
    return result;
  }

  @Override
  public int compareTo(SnmpProxyId o) {
    int c = objectName.compareTo(o.getObjectName());
    if (c == 0) {
      c = getContextName() != null ? getContextName().compareTo(o.getContextName()) :
          (o.getContextName() == null) ? 0 : -1;
      if (c == 0) {
        c = getModuleName() != null ? getModuleName().compareTo(o.getModuleName()) :
            (o.getModuleName() == null) ? 0 : -1;
        if (c == 0) {
          if (indexValues != null && o.indexValues != null) {
            c = indexValues.length - o.indexValues.length;
            if (c == 0) {
              for (int i = 0; (c == 0) && (i < indexValues.length); i++) {
                c = ((Comparable) indexValues[i]).compareTo(o.indexValues[i]);
              }
            }
          }
        }
      }
    }
    return c;
  }
}
