/*_############################################################################
  _## 
  _##  SNMP4J-Model - MutableSnmpProxy.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.model.snmp.proxy.impl.SnmpValuesChangeSet;
import org.snmp4j.model.snmp.spi.SnmpProxyCommitter;

/**
 * The MutableSnmpProxy interface provides a method to change a proxied value
 * of a {@link org.snmp4j.model.snmp.proxy.SnmpProxyObject}.
 *
 * @author Frank Fock
 */
public interface MutableSnmpProxy {

  SnmpProxyCommitter getCommitter();

  /**
   * Perform a change by adding it to the committer queue.
   * @param changeSet
   *   the change to perform atomically.
   * @return
   *   <code>true</code> if the change passed validation and thus was successfully added to the queue.
   */
  boolean doChange(SnmpValuesChangeSet changeSet);

  /**
   * Undo a change by adding the compensation change to the committer queue.
   * @param changeSet
   *   the change to undo atomically.
   * @return
   *   <code>true</code> if the undo change passed validation and thus was successfully added to the queue.
   */
  boolean undoChange(SnmpValuesChangeSet changeSet);

}
