/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpProxyColumn.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.smi.MaxAccess;
import org.snmp4j.smi.OID;

/**
 * The <code>SnmpProxyColumn</code> represents {@link SnmpProxyObject} of a SNMP columnar object.
 * @param <T>
 *   the model value type for this column.
 *
 * @author Frank Fock
 */
public interface SnmpProxyColumn<T> {

  /**
   * Gets the instance OID of the SNMP columnar object associated with this proxy column.
   * @return
   *    a column OID.
   */
  OID getOID();

  /**
   * Gets the class of the model value type.
   * @return
   *   the class of the model value.
   */
  Class<T> getValueClass();

  /**
   * Gets the minimum width of the column's values in characters.
   * @return
   *    the minimum character width.
   */
  int getMinWidth();

  /**
   * Gets the maximum width of the column's values in characters.
   * @return
   *    the maximum character width.
   */
  int getMaxWidth();

  /**
   * Gets the header string for the column.
   * @return
   *    the column header string.
   */
  String getHeader();

  /**
   * Gets the SMI maximum access for this column.
   * @return
   *    the maximum access as defined by the corresponding MIB.
   */
  MaxAccess getSmiMaxAccess();

  /**
   * Gets the SMI syntax (i.e., BER code) for the base syntax of this columnar SNMP object type.
   * @return
   *   the SMI syntax ID for this column.
   */
  int getSmiSyntax();

}
