/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpProxyObject.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.Target;
import org.snmp4j.model.mapper.VariableBindingMapper;
import org.snmp4j.model.snmp.spi.SnmpProxyReloadListener;
import org.snmp4j.model.snmp.spi.SnmpService;
import org.snmp4j.smi.OID;
import org.snmp4j.smi.OctetString;

/**
 * The <code>SnmpProxyObject</code> interface provides the basic characteristics for a proxy object for some
 * SNMP entity data.
 *
 * @author Frank Fock
 */
public interface SnmpProxyObject {

  /**
   * Gets the unique identifier of this proxy object. Typically this is the root OID of the MIB objects
   * managed by this proxy. If the proxy manages a single instance only, this should be the instance
   * identifier.
   * @return
   *    the OID for this proxy object.
   */
  OID getOID();

  /**
   * Reload the model content of the proxy object from the target SNMP entity asynchronously in the background.
   * @param snmpService
   *   the SNMP service to use.
   * @param target
   *   the SNMP target (i.e., address, timeouts, etc.) to use.
   * @param variableBindingMapper
   *   the variable binding mapper that maps the retrieved SNMP values to model values (based on SNMP types or
   *   specific OID based mappings).
   * @param reloadListener
   *   a callback listener that is informed about the reloading status.
   * @return
   *   the task ID for the background task.
   */
  TaskId reload(SnmpService snmpService, Target target, VariableBindingMapper variableBindingMapper,
                SnmpProxyReloadListener reloadListener);

  /**
   * Wait until the specified background task terminates.
   * @param taskId
   *   the task ID of the task to wait for.
   * @param timeout
   *   the maximum time to wait in millis.
   * @return
   *   <code>true</code> if the task has terminated, <code>false</code> otherwise.
   */
  boolean waitForTask(TaskId taskId, long timeout);

  /**
   * Get the context of the proxy object.
   * @return
   *    the context associated with this proxy object.
   */
  OctetString getContext();

}
