/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpProxyRow.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.model.snmp.spi.SnmpErrorStatus;
import org.snmp4j.smi.OID;

import java.util.Iterator;
import java.util.List;

/**
 * The SnmpProxyRow interface provides access to a row in a {@link org.snmp4j.model.snmp.proxy.SnmpTable}.
 * @param <IT>
 *   the class of the index column object values. Typically this depends on the index columns and can thus be only a
 *   superclass or the Object class.
 * @param <T>
 *   the class of the column object values. Typically this depends on the column and can thus be only a superclass or
 *   the Object class.
 * @author Frank Fock
 */
public interface SnmpProxyRow<IT,T> {

  /**
   * Gets the SNMP row index (the OID suffix that identifies a row in this table).
   * @return
   *   an index OID.
   */
  OID getIndex();

  List<IT> getIndexObjects();

  List<T> getValues();

  IT getIndexValue(int indexColumn);

  T getValue(int columnIndex);

  void setValue(int columnIndex, T value);

  SnmpErrorStatus getError(int columnIndex);

  /**
   * Returns the number of elements in this row.
   * @return
   *    the number of elements.
   */
  int size();
}
