/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpTableRO.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.model.snmp.proxy.impl.SnmpValuesChangeSet;
import org.snmp4j.model.snmp.spi.SnmpCell;
import org.snmp4j.model.snmp.spi.SnmpErrorStatus;
import org.snmp4j.smi.OID;
import org.snmp4j.smi.VariableBinding;

import javax.swing.table.TableColumnModel;
import javax.swing.table.TableModel;
import java.util.List;

/**
 * The SnmpTableRO object is a proxy to for a read-only SNMP table object.
 * @param <IC>
 *   the index proxy column type for the table proxy.
 * @param <C>
 *   the proxy column type fo the table proxy.
 * @param <IT>
 *   the model value type for index columns.
 * @param <T>
 *   the model value type for the columnar model values.
 * @param <R>
 *   the proxy row type for the rows of the table.
 *
 * @author Frank Fock
 */
public interface SnmpTableRO<IC extends SnmpProxyIndexColumn, C extends SnmpProxyColumn,
    IT, T, R extends SnmpProxyRow<IT,T>>
    extends SnmpProxyObject, TableModel, SnmpTableUpdateListener<R> {

  /**
   * Gets the table entry OID (thus including the <code>.1</code> suffix) for the associated SNMP table.
   * @return
   *   the table entry OID.
   */
  OID getOID();

  /**
   * Gets the list of columnar proxy objects of this table.
   * @return
   *    the list of column proxy objects.
   */
  List<C> getColumns();

  /**
   * Gets the list of index columnar proxy objects of this table.
   * @return
   *    the list of index column proxy objects.
   */
  List<IC> getIndexColumns();

  /**
   * Sets the page size for this table. For any value greater than zero, the {@link TableModel} will view only
   * a single page of rows of this proxy table.
   * @param numRows
   *   the number of rows in the table.
   */
  void setPageSize(int numRows);

  /**
   * Gets the page size.
   * @return
   *   the maximum number of rows in a page. If zero or less is returned, then there is no limit.
   */
  int getPageSize();

  void setCurrentIndex(int startPos);

  int getCurrentIndex();

  void setRowFilter(SnmpProxyRowFilter rowFilter);

  SnmpProxyRowFilter getRowFilter();

  void setMinIndex(Object[] minIndex);
  Object[] getMinIndex();

  List<VariableBinding> getIndexVariableBindings(OID index);

  SnmpProxyRowFactory<R,IT,T> getRowFactory();

  int getRowNumber(OID index);
  int getColumnNumber(OID columnOID);

  TableColumnModel getTableColumnModel(int maxCharacterPixelWidth, int maxColumnCharacters);

  void addError(List<SnmpValuesChangeSet> valuesChangeSets, SnmpErrorStatus errorStatus, int errorIndex);

  SnmpErrorStatus getError(OID rowIndex, int column);

  void clearAllErrors();

  SnmpErrorStatus clearError(OID rowIndex);

  List<OID> getRowIndexes();

  OID getRowIndex(int rowNumber);

  SnmpCell getCell(OID instanceOID);
}
