/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpTableUpdateListener.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.model.snmp.proxy.SnmpProxyRow;

/**
 * The {@link SnmpTableUpdateListener} interface provides callbacks for table updates.
 * @author Frank Fock
 */
public interface SnmpTableUpdateListener<R extends SnmpProxyRow> {

  /**
   * This method is called when a table update begins.
   * @param updateID
   *    the ID of the update procedure.
   */
  void beginUpdate(Object updateID);

  /**
   * This method is called when the provided row has been updated.
   * @param updateID
   *    the ID of the update procedure.
   * @param updateRow
   *    the updated row.
   */
  void updateRow(Object updateID, R updateRow);

  /**
   * This method is called when the update with the given update ID has been finished.
   * @param updateID
   *    the ID of the update procedure.
   */
  void finishUpdate(Object updateID);
}
