/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpCommitResult.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.spi;

import org.snmp4j.model.snmp.proxy.impl.SnmpValuesChangeSet;
import org.snmp4j.smi.VariableBinding;

import java.util.List;

/**
 * The SnmpCommitResult class provides information about the success or failure of a
 * {@link org.snmp4j.model.transaction.TransactionManager#commit(org.snmp4j.model.transaction.SnmpTransaction)}
 * operation.
 *
 * @author Frank Fock
 */
public interface SnmpCommitResult<T> {

  /**
   * Returns <code>true</code> if the commit operation succeeded.
   * @return
   *    <code>true</code> if the commit operation succeeded, <code>false</code> if a timeout, IO exception,
   *    or SNMP error occurred.
   */
  boolean isSuccess();

  SnmpErrorStatus getErrorStatus();

  List<SnmpValuesChangeSet> getFailedChanges();

  List<SnmpValuesChangeSet> getCommittedChanges();

  /**
   * Gets the error index of the SNMP error (if > 0) that points to the {@link org.snmp4j.smi.VariableBinding}
   * in {@link #getFailedChanges()} ()} that caused the error.
   * @return
   *    0 if no specific variable binding caused an error or a value > 0 that points to the n-th variable binding
   *    in {@link #getFailedChanges()} ()} that caused the error.
   */
  int getErrorIndex();

}
