/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpProxyReloadListener.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.spi;

import org.snmp4j.model.snmp.proxy.SnmpProxyObject;
import org.snmp4j.model.snmp.spi.SnmpErrorStatus;
import org.snmp4j.smi.OID;

import java.util.List;

/**
 * The <code>SnmpProxyReloadListener</code> interface receives updates on the reload status of proxy objects.
 *
 * @author Frank Fock
 */
public interface SnmpProxyReloadListener {

  /**
   * The reload operation for the specified proxy object has been finished.
   * @param proxyObject
   *   the proxy object that was reloaded.
   */
  void reloadFinished(SnmpProxyObject proxyObject);

  /**
   * The reload operation for the specified proxy object has failed (most likely the reload was not executed at all
   * or only partyl).
   * @param proxyObject
   *   the proxy object that should have been reloaded.
   * @param status
   *   the SNMP error status indicating the failure reason.
   */
  void reloadFailed(SnmpProxyObject proxyObject, SnmpErrorStatus status);

}
