/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpProxyReloader.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.spi;

import org.snmp4j.model.snmp.proxy.SnmpProxyObject;
import org.snmp4j.model.snmp.proxy.TaskId;

import java.util.List;

/**
 * The <code>SnmpProxyReloader</code> interface defines methods to reload proxy objects.
 *
 * @author Frank Fock
 */
public interface SnmpProxyReloader {

  /**
   * Queue a proxy object for reload. No communication with the SNMP target will be performed yet, until
   * {@link #reloadQueued(SnmpProxyReloadListener)} is called.
   * @param proxyObject
   *   the proxy object to reload.
   */
  void queueReload(SnmpProxyObject proxyObject);

  /**
   * Actually reload all queued proxy objects asynchronously in background.
   * @param reloadListener
   *   the callback listener which receives updates on the reload process.
   * @return
   *   a list of {@link TaskId} instances for the each affected proxy object. If a reload
   *   for a proxy object failed to start (because of network issues or incorrect target definitions),
   *   <code>null</code> is returned for that element.
   */
  List<TaskId> reloadQueued(SnmpProxyReloadListener reloadListener);


}
