/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpRow.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.spi;

import org.snmp4j.smi.OID;
import org.snmp4j.smi.Variable;
import org.snmp4j.smi.VariableBinding;

import java.util.Arrays;
import java.util.List;

/**
 * The SnmpProxyRow object represents a row of a SNMP table. Such a row can contain columnar objects
 * from different SMI tables, but those rows all have a common index value (oid suffix after the
 * respective table OID).
 *
 * @author Frank Fock
 */
public class SnmpRow {

  private OID index;

  private List<VariableBinding> variableBindings;

  public SnmpRow(OID index, List<VariableBinding> variableBindings) {
    this.index = index;
    this.variableBindings = variableBindings;
  }

  public OID getIndex() {
    return index;
  }

  public List<VariableBinding> getVariableBindings() {
    return variableBindings;
  }

  public Variable getColumn(OID columnOID) {
    for (VariableBinding vb : variableBindings) {
      if (vb.getOid().startsWith(columnOID)) {
        return vb.getVariable();
      }
    }
    return null;
  }

  @Override
  public String toString() {
    return "SnmpProxyRow{" +
        "index=" + index +
        ", variableBindings=" + variableBindings +
        '}';
  }
}
