/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpRowListener.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.spi;

import org.snmp4j.model.snmp.proxy.TaskId;

/**
 * Implementations of the <code>SnmpRowListener</code> may receive row based status updates when a table is being
 * updated by a reload operation.
 *
 * @author Frank Fock
 */
public interface SnmpRowListener extends TaskId {

  /**
   * Indicates that an update begins for the given user object reference.
   * @param userObject
   *   the user object reference identifying the update process.
   */
  void beginUpdate(Object userObject);

  /**
   * Provides the next row to this row listener. The listener returns <code>false</code>
   * if it does not want to receive any further event on this update (cancels the update).
   * @param nextRow
   *    the next row of the update.
   * @param userObject
   *    the user object provided when the async update procedure was initiated.
   * @return
   *    <code>true</code> while further rows should be provided to the listener.
   */
  boolean nextRow(SnmpRow nextRow, Object userObject);

  /**
   * Indicates that an update ended for the given user object reference.
   * @param errorStatus
   *   the error status. If there was no error: <code>null</code>.
   * @param userObject
   *   the user object reference identifying the update process.
   */
  void endUpdate(SnmpErrorStatus errorStatus, Object userObject);

}
