/*_############################################################################
  _## 
  _##  SNMP4J-Model - TransactionManager.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/

package org.snmp4j.model.transaction;

import org.snmp4j.model.snmp.proxy.SnmpCommitListener;
import org.snmp4j.model.snmp.spi.SnmpCommitResult;
import org.snmp4j.model.snmp.spi.SnmpErrorStatus;

import java.util.List;

/**
 * This is the central interface for SNMP transaction management with SNMP4J
 * command generator applications.
 *
 * @author Frank Fock
 */
public interface TransactionManager {

  /**
   * Commits the transaction to the agent.
   * @param transaction
   *    the transaction to commit.
   * @param commitListener
   *    the optional listener that is immediately informed during this commit call about
   *    failures and successful committed change sets.
   * @return
   *    the {@link org.snmp4j.model.snmp.spi.SnmpErrorStatus} indicating success or failure reason
   *    of the transaction.
   */
  List<? extends SnmpCommitResult> commit(SnmpTransaction transaction, SnmpCommitListener commitListener);

  void rollback(SnmpTransaction transaction);

  SnmpTransaction getSnmpTransaction(SnmpTransactionStrategy transactionStrategy);

  /**
   * Checks if this transaction can be committed with atomicity. As SNMP
   * guarantees atomicity only for a single SET PDU. That is, if a transaction
   * cannot be completed with a single SET PDU (message), this method will return
   * <code>false</code>.
   *
   * @param transaction
   *    the transaction to test.
   * @return
   *    <code>true</code> if this transaction can be committed by using a single
   *    SET PDU. Thus, the variables to set do not exceed the target's maximum
   *    size PDU length (including estimated SNMP message overhead).
   */
  boolean isAtomic(SnmpTransaction transaction);

}
