/*_############################################################################
  _## 
  _##  SNMP4J-Model - SimpleAbstractTreeTableModel.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.demo.mibbrowser;

import javax.swing.event.EventListenerList;
import javax.swing.event.TreeModelEvent;
import javax.swing.event.TreeModelListener;
import javax.swing.tree.TreePath;

/**
 * The <code>SimpleAbstractTreeTableModel</code> is an abstract implementation of
 * the {@link org.snmp4j.model.demo.mibbrowser.SimpleTreeTableModel} that provides
 * means to observe tree changes.
 *
 * @author Frank Fock
 * @version 1.0
 */
public abstract class SimpleAbstractTreeTableModel implements SimpleTreeTableModel {

  protected Object root;
  protected EventListenerList listenerList = new EventListenerList();

  private static final int CHANGED = 0;
  private static final int INSERTED = 1;
  private static final int REMOVED = 2;
  private static final int STRUCTURE_CHANGED = 3;

  public SimpleAbstractTreeTableModel(Object root) {
    this.root = root;
  }

  public Object getRoot() {
    return root;
  }

  public boolean isLeaf(Object node) {
    return getChildCount(node) == 0;
  }

  public void valueForPathChanged(TreePath path, Object newValue) {
  }

  /**
   * Generally not called by Swing -> thus not implemented here.
   */
  public int getIndexOfChild(Object parent, Object child) {
    return 0;
  }

  public void addTreeModelListener(TreeModelListener l) {
    listenerList.add(TreeModelListener.class, l);
  }

  public void removeTreeModelListener(TreeModelListener l) {
    listenerList.remove(TreeModelListener.class, l);
  }

  private void fireTreeNode(int changeType, Object source, Object[] path, int[] childIndices, Object[] children) {
    Object[] listeners = listenerList.getListenerList();
    TreeModelEvent e = new TreeModelEvent(source, path, childIndices, children);
    for (int i = listeners.length - 2; i >= 0; i -= 2) {
      if (listeners[i] == TreeModelListener.class) {

        switch (changeType) {
          case CHANGED:
            ((TreeModelListener) listeners[i + 1]).treeNodesChanged(e);
            break;
          case INSERTED:
            ((TreeModelListener) listeners[i + 1]).treeNodesInserted(e);
            break;
          case REMOVED:
            ((TreeModelListener) listeners[i + 1]).treeNodesRemoved(e);
            break;
          case STRUCTURE_CHANGED:
            ((TreeModelListener) listeners[i + 1]).treeStructureChanged(e);
            break;
          default:
            break;
        }

      }
    }
  }

  protected void fireTreeNodesChanged(Object source, Object[] path, int[] childIndices, Object[] children) {
    fireTreeNode(CHANGED, source, path, childIndices, children);
  }

  protected void fireTreeNodesInserted(Object source, Object[] path, int[] childIndices, Object[] children) {
    fireTreeNode(INSERTED, source, path, childIndices, children);
  }

  protected void fireTreeNodesRemoved(Object source, Object[] path, int[] childIndices, Object[] children) {
    fireTreeNode(REMOVED, source, path, childIndices, children);
  }

  protected void fireTreeStructureChanged(Object source, Object[] path, int[] childIndices, Object[] children) {
    fireTreeNode(STRUCTURE_CHANGED, source, path, childIndices, children);
  }


}
