/*_############################################################################
  _## 
  _##  SNMP4J-Model - SimpleMibDataNode.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.demo.mibbrowser;

import com.snmp4j.smi.*;
import org.snmp4j.model.snmp.proxy.SnmpScalarRO;
import org.snmp4j.smi.OID;
import org.snmp4j.model.snmp.proxy.SnmpProxyObject;
import org.snmp4j.smi.Variable;

import java.util.Collections;
import java.util.List;

/**
 * The SimpleMibDataNode class specifies a simple MIB tree node with SMI information.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class SimpleMibDataNode implements SmiObject, SmiValueType {

  private List<SimpleMibDataNode> children;

  private SmiObject smiObject;

  private SnmpProxyObject proxyObject;

  public SimpleMibDataNode(SmiObject smiObject, SnmpProxyObject proxyObject) {
    this.smiObject = smiObject;
    this.proxyObject = proxyObject;
  }

  public void setChildren(List<SimpleMibDataNode> children) {
    this.children = children;
  }

  @Override
  public String getObjectName() {
    return smiObject.getObjectName();
  }

  @Override
  public OID getOID() {
    return smiObject.getOID();
  }

  @Override
  public int getSmiSyntax() {
    return smiObject.getSmiSyntax();
  }

  public int getSnmpSyntax() {
    return (proxyObject instanceof org.snmp4j.model.snmp.proxy.SnmpScalar) ?
        ((org.snmp4j.model.snmp.proxy.SnmpScalar)proxyObject).getSnmpSyntax() : -1;
  }

  @Override
  public String getDescription() {
    return smiObject.getDescription();
  }

  @Override
  public SmiType getType() {
    return smiObject.getType();
  }

  @Override
  public List<? extends SmiObject> getChildren() {
    return children;
  }

  @Override
  public SmiObject getParent() {
    return null; // not supported
  }

  @Override
  public String getReference() {
    return smiObject.getReference();
  }

  @Override
  public SmiSyntax getSyntax() {
    return (smiObject instanceof SmiValueType) ? ((SmiValueType)smiObject).getSyntax(): null;
  }

  @Override
  public SmiStatus getStatus() {
    return smiObject.getStatus();
  }

  @Override
  public String[] getAsn1Comments() {
    return smiObject.getAsn1Comments();
  }

  public SmiObject getSmiObject() {
    return smiObject;
  }

  public Object getValue() {
    if (proxyObject instanceof org.snmp4j.model.snmp.proxy.SnmpScalarRO) {
      return ((org.snmp4j.model.snmp.proxy.SnmpScalarRO)proxyObject).getValue();
    }
    return null;
  }

  public SnmpProxyObject getProxyObject() {
    return proxyObject;
  }

  public String toString() {
    return smiObject.getObjectName();
  }
}
