/*_############################################################################
  _## 
  _##  SNMP4J-Model - SimpleMibTreeTableCellRenderer.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.demo.mibbrowser;

import javax.swing.*;
import javax.swing.table.TableCellRenderer;
import javax.swing.tree.TreeModel;
import java.awt.*;

/**
 * The <code>SimpleMibTreeTableCellRenderer</code> renders a table cell within a table node of tree.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class SimpleMibTreeTableCellRenderer extends JTree implements TableCellRenderer {
    /**
     * The last row that is rendered.
     */
    protected int visibleRow;

    private SimpleMibTreeTable treeTable;

    public SimpleMibTreeTableCellRenderer(SimpleMibTreeTable treeTable, TreeModel model) {
      super(model);
      this.treeTable = treeTable;
      setRowHeight(getRowHeight());
    }

    /**
     * Tree und Table must have the same height.
     */
    public void setRowHeight(int rowHeight) {
      if (rowHeight > 0) {
        super.setRowHeight(rowHeight);
        if (treeTable != null && treeTable.getRowHeight() != rowHeight) {
          treeTable.setRowHeight(getRowHeight());
        }
      }
    }

    /**
     * Tree und Table must have the same height.
     */
    public void setBounds(int x, int y, int w, int h) {
      super.setBounds(x, 0, w, treeTable.getHeight());
    }

    /**
     * Provides the indentation of the folders.
     */
    public void paint(Graphics g) {
      g.translate(0, -visibleRow * getRowHeight());
      super.paint(g);
    }

    public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {
      if (isSelected)
        setBackground(table.getSelectionBackground());
      else
        setBackground(table.getBackground());

      visibleRow = row;
      return this;
    }

}
