/*_############################################################################
  _## 
  _##  SNMP4J-Model - SimpleMibTreeTableModel.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.demo.mibbrowser;

import com.snmp4j.smi.SmiObjectType;
import com.snmp4j.smi.SmiValueType;
import org.snmp4j.smi.SMIConstants;

import java.text.SimpleDateFormat;

/**
 * The <code>SimpleMibTreeTableModel</code> is a demo implementation of a simple tree table model for MIB viewing.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class SimpleMibTreeTableModel extends SimpleAbstractTreeTableModel {

  protected static String[] columnNames = { "MIB Object", "Value", "Syntax", "OID", "Max-Access", "Description" };

  protected static Class<?>[] columnTypes =
      { SimpleMibTreeTableModel.class, String.class, String.class, String.class, String.class, String.class };

  protected static boolean[] editableColumns = {
      true, false, false, false, false, false
  };

  public SimpleMibTreeTableModel(SimpleMibDataNode rootNode) {
    super(rootNode);
    root = rootNode;
  }

  public Object getChild(Object parent, int index) {
    return ((SimpleMibDataNode) parent).getChildren().get(index);
  }


  public int getChildCount(Object parent) {
    if ((! (parent instanceof SimpleMibDataNode)) || (((SimpleMibDataNode) parent).getChildren() == null)) {
      return 0;
    }
    return ((SimpleMibDataNode) parent).getChildren().size();
  }


  public int getColumnCount() {
    return columnNames.length;
  }


  public String getColumnName(int column) {
    return columnNames[column];
  }


  public Class<?> getColumnClass(int column) {
    return columnTypes[column];
  }

  public Object getValueAt(Object node, int column) {
    SimpleMibDataNode dataNode = (SimpleMibDataNode)node;
    try {
      switch (column) {
        case 0:
          return ""+dataNode.getObjectName();
        case 1:
          return (dataNode.getValue() == null) ? "" : dataNode.getValue();
        case 2:
          if (dataNode.getSmiObject() instanceof SmiValueType) {
            return ""+((SmiValueType)dataNode.getSmiObject()).getSyntax().getSyntaxClause();
          }
          return "";
        case 3:
          return ""+dataNode.getOID().toDottedString();
        case 4:
          return dataNode.getSmiObject() instanceof SmiObjectType ?
              ""+((SmiObjectType)dataNode.getSmiObject()).getMaxAccess() : "";
        case 5:
          return dataNode.getDescription();
        default:
          break;
      }
    }
    catch (NullPointerException npe) {
      //npe.printStackTrace();
      return null;
    }
    return null;
  }

  public boolean isCellEditable(Object node, int column) {
    return  editableColumns[column]; // important that first column is "editable" to activate TreeExpandListener
  }

  public void setValueAt(Object aValue, Object node, int column) {
  }


}
