package org.snmp4j.model.snmp.api;

import org.snmp4j.model.snmp.proxy.*;
import org.snmp4j.model.snmp.proxy.impl.SnmpScalarImpl;
import org.snmp4j.model.snmp.proxy.impl.SnmpTableImpl;
import org.snmp4j.model.snmp.spi.SnmpProxyCommitter;
import org.snmp4j.model.snmp.spi.SnmpProxyFactory;
import org.snmp4j.smi.OID;
import org.snmp4j.smi.OctetString;

import java.util.List;

/**
 * The {@link DefaultSnmpProxyRegistry} implements a {@link org.snmp4j.model.snmp.spi.SnmpProxyFactory}
 * for the proxy objects defined in the <code>org.snmp4j.proxy.impl</code> package.
 *
 * @param <T> the value representation (base) type, i.e. {@link java.lang.String} if you use a
 * {@link org.snmp4j.model.mapper.VariableBindingMapper} that provides {@link java.lang.String} instances for all
 * Snmp types.
 * @param <IC>
 *   the index proxy column type for the table proxy.
 * @param <C>
 *   the proxy column type for the table proxy.
 * @param <IT>
 *   the model value type for index columns.
 * @param <R>
 *   the proxy row type for the rows of the table.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class DefaultSnmpProxyFactory<T,C extends SnmpProxyColumn<T>,IC extends SnmpProxyIndexColumn<T>,
    IT,R extends SnmpProxyRow<IT, T>> implements SnmpProxyFactory<T,C,IC,IT,R> {

  @Override
  public SnmpScalar<T> createSnmpScalar(OID oid, OctetString context, SnmpProxyCommitter snmpProxyCommitter,
                                        T value, Class<T> valueClass, int snmpSyntax) {
    return new SnmpScalarImpl<T>(oid, context, value, valueClass, snmpSyntax, snmpProxyCommitter);
  }

  @Override
  public SnmpTable<C, IC, IT, T, R> createSnmpTable(OID oid, OctetString context, SnmpProxyCommitter snmpProxyCommitter,
                                                    SnmpProxyRowFactory<R, IT, T> rowFactory,
                                                    List<IC> snmpIndexColumns,
                                                    List<C> snmpColumns, int pageSize) {
    return new SnmpTableImpl<IC, C, IT, T, R>(oid, context, snmpProxyCommitter,
        rowFactory, snmpIndexColumns, snmpColumns, pageSize);
  }
}
