/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpCommitListener.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.model.snmp.proxy.impl.SnmpValuesChangeSet;
import org.snmp4j.model.snmp.spi.SnmpErrorStatus;
import org.snmp4j.smi.OctetString;

import java.util.List;

/**
 * Implementations of <code>SnmpCommitListener</code> interface listen for commit events.
 * @author Frank Fock
 */
public interface SnmpCommitListener {

  /**
   * Indication of a successful commit.
   * @param committedChanges
   *    the list of successfully committed change sets (each change set was committed atomically for itself).
   */
  void commitSuccess(List<SnmpValuesChangeSet> committedChanges);

  /**
   * Indicates a failed commit operation.
   * @param failedChanges
   *   the changes that failed to commit (none of the changes within a single change set must have been committed, if
   *   the change set was small enough to be committed atomically).
   * @param errorStatus
   *   the SNMP error status of the first failed change set.
   * @param errorIndex
   *   the index in the original list of changes committed that failed (zero based).
   */
  void commitFailure(List<SnmpValuesChangeSet> failedChanges, SnmpErrorStatus errorStatus,
                     int errorIndex);


  /**
   * Gets the SNMP context for the commit operation.
   * @return
   *    a context name (or <code>null</code>/empty octet string for the default context).
   */
  OctetString getContext();
}
