/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpProxyColumnFactory.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.model.snmp.proxy.impl.SnmpIndexColumn;
import org.snmp4j.smi.MaxAccess;
import org.snmp4j.smi.OID;
import org.snmp4j.smi.SubIndexInfo;

/**
 * The <code>SnmpProxyColumnFactory</code> interface defines how index column and column proxies should be created.
 *
 * @author Frank Fock
 */
public interface SnmpProxyColumnFactory<T> {

  /**
   * Creates a new proxy column.
   * @param oid
   *    the object identifier of the columnar MIB object. For example, for the column ifDescr this would be
   *    <code>new OID(1.3.6.1.2.1.2.2.1.2)</code>.
   * @param valueClass
   *    the class of the value representation for this column within the model.
   * @param smiMaxAccess
   *    the maximum access that should be supported by the model for this column (the access right should be
   *    less or equal to the maximum access right defined by the corresponding MIB).
   * @param smiSyntax
   *    the SMI syntax of the object.
   * @param minWidth
   *    the minimum width in characters of the values for this column. This servers as a hint
   *    for the column size calculation when this model is being rendered for display.
   * @param maxWidth
   *    the maximum width in characters of the values of this column. This servers as a hint
   *    for the column size calculation when this model is being rendered for display.
   * @param header
   *    the header string for this column (this value is not actually used by the proxy but can be used
   *    by a column renderer.
   * @return
   *    the new proxy column.
   */
  SnmpProxyColumn<T> createSnmpProxyColumn(OID oid, Class<T> valueClass, MaxAccess smiMaxAccess, int smiSyntax,
                                           int minWidth, int maxWidth, String header);

  /**
   * Creates a new index proxy column. Index proxy columns are used for representing index sub-identifiers as columns
   * in a model table.
   * @param oid
   *    the OID of the columnar object that represents this (sub-)index column.
   * @param valueClass
   *    the value class of the index column's value.
   * @param smiSyntax
   *    the SMI syntax of the index column.
   * @param minWidth
   *    the minimum width in characters of the values for this column. This servers as a hint
   *    for the column size calculation when this model is being rendered for display.
   * @param maxWidth
   *    the maximum width in characters of the values of this column. This servers as a hint
   *    for the column size calculation when this model is being rendered for display.
   * @param header
   *    the header string for this column (this value is not actually used by the proxy but can be used
   *    by a column renderer.
   * @param subIndexInfo
   *    the description of the index.
   * @return
   *    the new index proxy column.
   */
  SnmpIndexColumn<T> createSnmpProxyIndexColumn(OID oid, Class<T> valueClass, int smiSyntax,
                                           int minWidth, int maxWidth, String header, SubIndexInfo subIndexInfo);


}
