/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpProxyRowFactory.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.smi.OID;
import org.snmp4j.smi.Variable;

import java.util.List;

/**
 * The <code>SnmpProxyRowFactory</code> implements a row factory for SNMP table proxies.
 * @param <R>
 *   specifies the {@link SnmpProxyRow} implementation that will be created by this factory.
 * @param <IT>
 *    The type of the index object values. This type can be used to define common
 *    type class for all columnar objects, like {@link String}. If the columns have different
 *    types, {@link Object} should be used.
 * @param <T>
 *    The type of the columnar object values. This type can be used to define common
 *    type class for all columnar objects, like {@link String}. If the columns have different
 *    types, {@link Object} should be used.
 *
 * @author Frank Fock
 */
public interface SnmpProxyRowFactory<R extends SnmpProxyRow<IT,T>, IT, T> {

  /**
   * Create a proxy row with a SNMP index value as {@link OID} and with the corresponding index model values
   * a columnar object values.
   *
   * @param index
   *   the SNMP row index value as an OID (the OID contains only the index suffix and not the table or column
   *   object prefix.
   * @param indexObjects
   *   the list of index object values in the model based value type(s).
   * @param values
   *   the list of columnar object values in model based type(s).
   * @return
   *   the newly create proxy row.
   */
  R createProxyRow(OID index, List<IT> indexObjects, List<T> values);

}
