/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpTable.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy;

import org.snmp4j.model.snmp.spi.SnmpCellUpdateListener;
import org.snmp4j.smi.OID;

import java.util.List;

/**
 * The <code>SnmpTable</code> defines the interface for writable table proxies.
 * @param <C>
 *   the proxy column type fo the table proxy.
 * @param <IC>
 *   the index proxy column type for the table proxy.
 * @param <IT>
 *   the model value type for index columns.
 * @param <T>
 *   the model value type for the columnar model values.
 * @param <R>
 *   the proxy row type for the rows of the table.
 */
public interface SnmpTable<C extends SnmpProxyColumn,
                           IC extends SnmpProxyIndexColumn, IT, T, R extends SnmpProxyRow<IT,T>>
    extends SnmpTableRO<IC, C, IT, T, R>, SnmpCommitListener, MutableSnmpProxy {

  /**
   * Insert a new row into the table. This adds a new change set to the {@link SnmpCommitListener}.
   * @param newRow
   *    the new proxy row.
   */
  void insertRow(R newRow);

  /**
   * Fire a table cell updated event to the associated {@link SnmpCellUpdateListener}.
   * @param row
   *    the zero based row number of the cell.
   * @param column
   *    the zero based (including index columns) column index of the cell.
   */
  void fireTableCellUpdated(int row, int column);

  /**
   * Remove all rows of the proxy table without changing the target SNMP table at all.
   */
  void clear();

  /**
   * Gets the cell update listener associated with this table.
   * @return
   *   the cell update listener of this table.
   */
  SnmpCellUpdateListener getCellUpdateListener();

  /**
   * Sets the cell update listener associated with this table.
   * @param cellUpdateListener
   *   the new cell update listener for this table.
   */
  void setCellUpdateListener(SnmpCellUpdateListener cellUpdateListener);

}
