/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpGroupImplRO.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy.impl;

import org.snmp4j.Target;
import org.snmp4j.model.mapper.VariableBindingMapper;
import org.snmp4j.model.snmp.spi.SnmpProxyReloadListener;
import org.snmp4j.model.snmp.proxy.SnmpScalarGroupRO;
import org.snmp4j.model.snmp.proxy.SnmpScalarRO;
import org.snmp4j.model.snmp.proxy.TaskId;
import org.snmp4j.model.snmp.spi.SnmpService;
import org.snmp4j.smi.OID;
import org.snmp4j.smi.OctetString;

import java.util.List;

/**
 * The <code>SnmpGroupImplRO</code> is a proxy object for a group of read-only scalar objects.
 * The scalars can be read-write objects based on their MIB definition, however they will be
 * not accessed by SET SNMP messages (PDUs) when using this proxy.
 *
 * @author Frank Fock
 */
public class SnmpGroupImplRO extends SnmpProxyObjectImpl implements SnmpScalarGroupRO {

  private List<SnmpScalarRO<?>> scalars;

  /**
   * Creates a group proxy object with an object identifier (this could be any unique OID
   * but is typically the OID of the common root node of the supplied scalars).
   * @param groupOID
   *   a unique identifier for this group.
   * @param context
   *    the SNMP context associated with this proxy object.
   * @param scalars
   *   the scalar objects that should build this group.
   */
  public SnmpGroupImplRO(OID groupOID, OctetString context, List<SnmpScalarRO<?>> scalars) {
    super(context, groupOID);
    this.scalars = scalars;
  }

  @Override
  public List<SnmpScalarRO<?>> getScalars() {
    return scalars;
  }

  @Override
  public void setScalars(List<SnmpScalarRO<?>> scalars) {
    this.scalars = scalars;
  }

  @Override
  public TaskId reload(SnmpService snmpService, Target target, VariableBindingMapper variableBindingMapper, SnmpProxyReloadListener reloadListener) {
    return null;
  }

  @Override
  public boolean waitForTask(TaskId taskId, long timeout) {
    return false;
  }
}
