/*_############################################################################
  _## 
  _##  SNMP4J-Model - SnmpProxyRowImpl.java  
  _## 
  _##  Copyright (C) 2013-2015  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.proxy.impl;

import org.snmp4j.model.snmp.proxy.SnmpProxyRow;
import org.snmp4j.model.snmp.spi.SnmpErrorStatus;
import org.snmp4j.smi.OID;

import java.util.List;

/**
 * The <code>SnmpProxyRowImpl</code> class implements a proxy for a SNMP table row.
 * @param <IT>
 *    The type of the index object values. This type can be used to define common
 *    type class for all columnar objects, like {@link String}. If the columns have different
 *    types, {@link Object} should be used.
 * @param <T>
 *    The type of the columnar object values. This type can be used to define common
 *    type class for all columnar objects, like {@link String}. If the columns have different
 *    types, {@link Object} should be used.
 *
 * @author Frank Fock
 */
public class SnmpProxyRowImpl<IT,T> implements SnmpProxyRow<IT,T> {

  private OID index;
  private List<IT> indexObjects;
  private List<T> columns;
  private SnmpErrorStatus errorStatus;
  private int errorIndex;

  public SnmpProxyRowImpl(OID index, List<IT> indexObjects, List<T> columns) {
    this.index = index;
    this.indexObjects = indexObjects;
    this.columns = columns;
  }

  @Override
  public OID getIndex() {
    return index;
  }

  @Override
  public List<IT> getIndexObjects() {
    return indexObjects;
  }

  @Override
  public List<T> getValues() {
    return columns;
  }

  @Override
  public IT getIndexValue(int indexColumn) {
    return indexObjects.get(indexColumn);
  }

  @Override
  public T getValue(int columnIndex) {
    return columns.get(columnIndex);
  }

  @Override
  public void setValue(int columnIndex, T value) {
    columns.set(columnIndex, value);
  }

  @Override
  public SnmpErrorStatus getError(int columnIndex) {
    if (columnIndex != errorIndex - 1) {
      return null;
    }
    return errorStatus;
  }

  public void setErrorStatus(int errorIndex, SnmpErrorStatus errorStatus) {
    this.errorIndex = errorIndex;
    this.errorStatus = errorStatus;
  }

  @Override
  public int size() {
    return columns.size();
  }

  @Override
  public String toString() {
    return "SnmpProxyRowImpl{" +
        "index=" + index +
        ", indexObjects=" + indexObjects +
        ", columns=" + columns +
        ", errorStatus=" + errorStatus +
        ", errorIndex=" + errorIndex +
        '}';
  }
}
